﻿package implement

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/dao"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_models.git/utils/logx"
	"fmt"
	"xorm.io/xorm"
)

func NewPlatformRevenueDataDb(engine *xorm.Engine) dao.PlatformRevenueDataDao {
	return &PlatformRevenueDataDb{Db: engine}
}

type PlatformRevenueDataDb struct {
	Db *xorm.Engine
}

func (p PlatformRevenueDataDb) PlatformRevenueDataInsert(platformRevenueData *model.PlatformRevenueData) (int, error) {
	_, err := p.Db.InsertOne(platformRevenueData)
	if err != nil {
		return 0, zhios_order_relate_logx.Error(err.Error())
	}
	return platformRevenueData.Id, nil
}

func (p PlatformRevenueDataDb) PlatformRevenueDataFindAndCount(page, limit int, startAt, endAt string, kind int) ([]model.PlatformRevenueData, int64, error) {
	var m []model.PlatformRevenueData
	session := p.Db.Where("")
	if kind > 0 {
		session = session.Where("kind = ?", kind)
	}
	if startAt != "" {
		session = session.Where("create_at >= ?", startAt)
	}
	if endAt != "" {
		session = session.Where("create_at <= ?", endAt)
	}
	total, err := session.Limit(limit, (page-1)*limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, zhios_order_relate_logx.Error(err.Error())
	}
	return m, total, nil
}

func (p PlatformRevenueDataDb) PlatformRevenueDataFindNotFinish() ([]model.PlatformRevenueData, error) {
	var m []model.PlatformRevenueData
	err := p.Db.Where("balance_times > ?", 0).Find(&m)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err.Error())
	}
	return m, nil
}

func (p PlatformRevenueDataDb) PlatformRevenueDataUpdateBySession(session *xorm.Session, m model.PlatformRevenueData, forceColumns ...string) (int64, error) {
	affected, err := session.ID(m.Id).Cols(forceColumns...).Update(&m)
	if err != nil {
		return 0, zhios_order_relate_logx.Error(err.Error())
	}

	return affected, nil
}

func (p PlatformRevenueDataDb) PlatformRevenueDataGetOneByParams(params map[string]interface{}) (*model.PlatformRevenueData, error) {
	var m model.PlatformRevenueData
	var query = fmt.Sprintf("%s =?", params["key"])
	if has, err := p.Db.Where(query, params["value"]).Get(&m); err != nil || has == false {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}
