package implement

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/dao"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	zhios_order_relate_utils "code.fnuoos.com/EggPlanet/egg_models.git/utils"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_models.git/utils/logx"
	"fmt"
	"reflect"
	"xorm.io/xorm"
)

func NewUserTagRecordsDb(engine *xorm.Engine) dao.UserTagRecordsDao {
	return &UserTagRecordsDb{Db: engine}
}

type UserTagRecordsDb struct {
	Db *xorm.Engine
}

func (u UserTagRecordsDb) UserTagRecordsGetOneByParams(params map[string]interface{}) (*model.UserTagRecords, error) {
	var m model.UserTagRecords
	var query = fmt.Sprintf("%s = ?", params["key"])
	if has, err := u.Db.Where(query, params["value"]).Get(&m); err != nil || has == false {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}

func (u UserTagRecordsDb) UserTagRecordsUpdateBySession(session *xorm.Session, uid interface{}, user *model.UserTagRecords, forceColumns ...string) (int64, error) {
	var (
		affected int64
		err      error
	)
	if forceColumns != nil {
		affected, err = session.Where("uid=?", uid).Cols(forceColumns...).Update(user)
	} else {
		affected, err = session.Where("uid=?", uid).Update(user)
	}
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func (u UserTagRecordsDb) UserTagRecordsDeleteBySession(session *xorm.Session, params map[string]interface{}) (int64, error) {
	if reflect.TypeOf(params["value"]).Kind() == reflect.Slice {
		return session.In(zhios_order_relate_logx.AnyToString(params["key"]), params["value"]).Delete(model.UserTagRecords{})
	} else {
		var query = fmt.Sprintf("%s =?", params["key"])
		return session.Where(query, params["value"]).Delete(model.UserTagRecords{})
	}
}

func (u UserTagRecordsDb) UserTagRecordsBatchInsertBySession(session *xorm.Session, userTagRecord []*model.UserTagRecords) (int64, error) {
	affected, err := session.Insert(userTagRecord)
	if err != nil {
		return 0, zhios_order_relate_logx.Error(err)
	}
	return affected, nil
}

func (u UserTagRecordsDb) UserTagRecordsFindByParams(params map[string]interface{}) (*[]model.UserTagRecords, error) {
	var m []model.UserTagRecords
	if reflect.TypeOf(params["value"]).Kind() == reflect.Slice {
		//指定In查询
		if err := u.Db.In(zhios_order_relate_utils.AnyToString(params["key"]), params["value"]).Find(&m); err != nil {
			return nil, zhios_order_relate_logx.Warn(err)
		}
	} else {
		var query = fmt.Sprintf("%s =?", params["key"])
		err := u.Db.Where(query, params["value"]).Find(&m)
		if err != nil {
			return nil, zhios_order_relate_logx.Error(err)
		}
	}
	return &m, nil
}

func (u UserTagRecordsDb) UserTagRecordsExist(uid int64, tagId int) (bool, error) {
	var m model.UserTagRecords
	session := u.Db.Where("tag_id = ?", tagId)
	if uid != 0 {
		session.And("uid = ?", uid)
	}
	exist, err := session.Exist(&m)
	if err != nil {
		return false, zhios_order_relate_logx.Error(err)
	}
	return exist, nil
}

func (u UserTagRecordsDb) UserTagRecordsDelete(uid int64, tagId int) (int64, error) {
	affected, err := u.Db.Where("uid = ?", uid).And("tag_id = ?", tagId).Delete(model.UserTagRecords{})
	if err != nil {
		return 0, zhios_order_relate_logx.Error(err)
	}
	return affected, nil
}

func (u UserTagRecordsDb) UserTagRecordsIsUsedBySession(session *xorm.Session, tagId int) (bool, error) {
	var m model.UserTagRecords
	exist, err := session.Where("tag_id = ?", tagId).Exist(&m)
	if err != nil {
		return false, zhios_order_relate_logx.Error(err)
	}
	return exist, nil
}
